# Test detail

test_run | 11feb_r812
project | syn_pysyn
host | gaudete
test_name | stis_etc_cases/testcrcounts/SpecSourcerateSpecCase17
contact | unknown
status | F
attn | Y
test_runner |
start_time | Wed Feb 11 17:38:57 2009
end_time | unknown
location |
tda_crrefer | /eng/ssb/syn_pysyn/cdbs_pinned/
tda_etcid | STISSPEC1372
tda_obsmode | stis,nuvmama,e230h,c2263
tda_pysyn_cdbs | /eng/ssb/syn_pysyn/cdbs_pinned/
tda_sigthresh | 0.01
tda_skylines | True
tda_spectrum | spec(earthshine.fits)*0.5+rn(spec(Zodi.fits),band(johnson,v),22.7,vegamag)+(spec(el1215a.fits)+spec(el1302a.fits)+spec(el1356a.fits)+spec(el2471a.fits))
tda_subset | False
tda_superthresh | 0.2
tda_thresh | 0.01
tra_discrepfrac | 0.13186302545
tra_discrepmax | 0.404756500843
tra_discrepmean | 0.000509309419814
tra_discrepmin | -0.0841477248917
tra_discrepstd | 0.0172468677105
tra_outliers | 85

back to treewalk